@@ -425,9 +425,12 @@ is_text_region_empty (GtkTextRegion *region)
 		GtkTextIter region_start;
 		GtkTextIter region_end;
 
-		gtk_text_region_iterator_get_subregion (&region_iter,
-							&region_start,
-							&region_end);
+		if (!gtk_text_region_iterator_get_subregion (&region_iter,
+							     &region_start,
+							     &region_end))
+		{
+			return TRUE;
+		}
 
 		if (!gtk_text_iter_equal (&region_start, &region_end))
 		{
@@ -459,7 +462,10 @@ get_first_subregion (GtkTextRegion *region,
 
 	while (!gtk_text_region_iterator_is_end (&region_iter))
 	{
-		gtk_text_region_iterator_get_subregion (&region_iter, start, end);
+		if (!gtk_text_region_iterator_get_subregion (&region_iter, start, end))
+		{
+			return FALSE;
+		}
 
 		if (!gtk_text_iter_equal (start, end))
 		{
@@ -495,9 +501,12 @@ get_last_subregion (GtkTextRegion *region,
 		GtkTextIter start_subregion;
 		GtkTextIter end_subregion;
 
-		gtk_text_region_iterator_get_subregion (&region_iter,
-							&start_subregion,
-							&end_subregion);
+		if (!gtk_text_region_iterator_get_subregion (&region_iter,
+							     &start_subregion,
+							     &end_subregion))
+		{
+			return FALSE;
+		}
 
 		if (!gtk_text_iter_equal (&start_subregion, &end_subregion))
 		{
@@ -1581,15 +1590,21 @@ scan_all_region (GtkSourceSearchContext *search,
 		return;
 	}
 
-	gtk_text_region_nth_subregion (region_to_highlight,
-				       0,
-				       &start_search,
-				       NULL);
+	if (!gtk_text_region_nth_subregion (region_to_highlight,
+					    0,
+					    &start_search,
+					    NULL))
+	{
+		return;
+	}
 
-	gtk_text_region_nth_subregion (region_to_highlight,
-				       nb_subregions - 1,
-				       NULL,
-				       &end_search);
+	if (!gtk_text_region_nth_subregion (region_to_highlight,
+					    nb_subregions - 1,
+					    NULL,
+					    &end_search))
+	{
+		return;
+	}
 
 	gtk_text_iter_order (&start_search, &end_search);
 
@@ -1779,15 +1794,21 @@ regex_search_handle_high_priority_region (GtkSourceSearchContext *search)
 		return;
 	}
 
-	gtk_text_region_nth_subregion (search->priv->high_priority_region,
-				       0,
-				       &start,
-				       NULL);
+	if (!gtk_text_region_nth_subregion (search->priv->high_priority_region,
+					    0,
+					    &start,
+					    NULL))
+	{
+		return;
+	}
 
-	gtk_text_region_nth_subregion (search->priv->high_priority_region,
-				       nb_subregions - 1,
-				       NULL,
-				       &end);
+	if (!gtk_text_region_nth_subregion (search->priv->high_priority_region,
+					    nb_subregions - 1,
+					    NULL,
+					    &end))
+	{
+		return;
+	}
 
 	region = gtk_text_region_intersect (search->priv->scan_region,
 					    &start,
@@ -1800,9 +1821,12 @@ regex_search_handle_high_priority_region (GtkSourceSearchContext *search)
 		GtkTextIter subregion_start;
 		GtkTextIter subregion_end;
 
-		gtk_text_region_iterator_get_subregion (&region_iter,
-							&subregion_start,
-							&subregion_end);
+		if (!gtk_text_region_iterator_get_subregion (&region_iter,
+							     &subregion_start,
+							     &subregion_end))
+		{
+			return;
+		}
 
 		gtk_text_buffer_remove_tag (search->priv->buffer,
 					    search->priv->found_tag,
@@ -2015,7 +2039,10 @@ regex_search_scan_next_chunk (GtkSourceSearchContext *search)
 		return;
 	}
 
-	gtk_text_region_nth_subregion (search->priv->scan_region, 0, &chunk_start, NULL);
+	if (!gtk_text_region_nth_subregion (search->priv->scan_region, 0, &chunk_start, NULL))
+	{
+		return;
+	}
 
 	chunk_end = chunk_start;
 	gtk_text_iter_forward_lines (&chunk_end, SCAN_BATCH_SIZE);
@@ -2073,6 +2100,13 @@ idle_scan_regex_search (GtkSourceSearchContext *search)
 static gboolean
 idle_scan_cb (GtkSourceSearchContext *search)
 {
+	if (search->priv->buffer == NULL)
+	{
+		search->priv->idle_scan_id = 0;
+		clear_search (search);
+		return G_SOURCE_REMOVE;
+	}
+
 	return gtk_source_search_settings_get_regex_enabled (search->priv->settings) ?
 	       idle_scan_regex_search (search) :
 	       idle_scan_normal_search (search);
@@ -3682,10 +3716,13 @@ _gtk_source_search_context_update_highlight (GtkSourceSearchContext *search,
 	{
 		GtkTextIter start;
 
-		gtk_text_region_nth_subregion (search->priv->scan_region,
-					       0,
-					       &start,
-					       NULL);
+		if (!gtk_text_region_nth_subregion (search->priv->scan_region,
+						    0,
+						    &start,
+						    NULL))
+		{
+			return;
+		}
 
 		regex_search_scan_chunk (search, &start, end);
 	}
